Module sys

Module sys 

Structs

__fsid_t
_openslide

Constants

INT8_MAX
INT8_MIN
INT16_MAX
INT16_MIN
INT32_MAX
INT32_MIN
INTPTR_MAX
INTPTR_MIN
INT_FAST8_MAX
INT_FAST8_MIN
INT_FAST16_MAX
INT_FAST16_MIN
INT_FAST32_MAX
INT_FAST32_MIN
INT_LEAST8_MAX
INT_LEAST8_MIN
INT_LEAST16_MAX
INT_LEAST16_MIN
INT_LEAST32_MAX
INT_LEAST32_MIN
OPENSLIDE_PROPERTY_NAME_BACKGROUND_COLOR
OPENSLIDE_PROPERTY_NAME_BOUNDS_HEIGHT
OPENSLIDE_PROPERTY_NAME_BOUNDS_WIDTH
OPENSLIDE_PROPERTY_NAME_BOUNDS_X
OPENSLIDE_PROPERTY_NAME_BOUNDS_Y
OPENSLIDE_PROPERTY_NAME_COMMENT
OPENSLIDE_PROPERTY_NAME_MPP_X
OPENSLIDE_PROPERTY_NAME_MPP_Y
OPENSLIDE_PROPERTY_NAME_OBJECTIVE_POWER
OPENSLIDE_PROPERTY_NAME_QUICKHASH1
OPENSLIDE_PROPERTY_NAME_VENDOR
PTRDIFF_MAX
PTRDIFF_MIN
SIG_ATOMIC_MAX
SIG_ATOMIC_MIN
SIZE_MAX
UINT8_MAX
UINT16_MAX
UINT32_MAX
UINTPTR_MAX
UINT_FAST8_MAX
UINT_FAST16_MAX
UINT_FAST32_MAX
UINT_LEAST8_MAX
UINT_LEAST16_MAX
UINT_LEAST32_MAX
WINT_MAX
WINT_MIN
_ATFILE_SOURCE
_BITS_STDINT_INTN_H
_BITS_STDINT_LEAST_H
_BITS_STDINT_UINTN_H
_BITS_TIME64_H
_BITS_TYPESIZES_H
_BITS_TYPES_H
_BITS_WCHAR_H
_DEFAULT_SOURCE
_FEATURES_H
_POSIX_C_SOURCE
_POSIX_SOURCE
_STDC_PREDEF_H
_STDINT_H
_SYS_CDEFS_H
__FD_SETSIZE
__GLIBC_MINOR__
__GLIBC_USE_C2X_STRTOL
__GLIBC_USE_DEPRECATED_GETS
__GLIBC_USE_DEPRECATED_SCANF
__GLIBC_USE_IEC_60559_BFP_EXT
__GLIBC_USE_IEC_60559_BFP_EXT_C2X
__GLIBC_USE_IEC_60559_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT
__GLIBC_USE_IEC_60559_FUNCS_EXT_C2X
__GLIBC_USE_IEC_60559_TYPES_EXT
__GLIBC_USE_ISOC2X
__GLIBC_USE_LIB_EXT2
__GLIBC__
__GNU_LIBRARY__
__HAVE_GENERIC_SELECTION
__INO_T_MATCHES_INO64_T
__KERNEL_OLD_TIMEVAL_MATCHES_TIMEVAL64
__LDOUBLE_REDIRECTS_TO_FLOAT128_ABI
__OFF_T_MATCHES_OFF64_T
__RLIM_T_MATCHES_RLIM64_T
__STATFS_MATCHES_STATFS64
__STDC_IEC_559_COMPLEX__
__STDC_IEC_559__
__STDC_IEC_60559_BFP__
__STDC_IEC_60559_COMPLEX__
__STDC_ISO_10646__
__SYSCALL_WORDSIZE
__TIMESIZE
__USE_ATFILE
__USE_FORTIFY_LEVEL
__USE_ISOC11
__USE_ISOC95
__USE_ISOC99
__USE_MISC
__USE_POSIX
__USE_POSIX2
__USE_POSIX199309
__USE_POSIX199506
__USE_POSIX_IMPLICITLY
__USE_XOPEN2K
__USE_XOPEN2K8
__WORDSIZE
__WORDSIZE_TIME64_COMPAT32
__bool_true_false_are_defined
__glibc_c99_flexarr_available
false_
true_

Functions

_openslide_cancel_prefetch_hint_UNIMPLEMENTED
_openslide_give_prefetch_hint_UNIMPLEMENTED
openslide_can_open
Return whether openslide_open() will succeed.
openslide_close
Close an OpenSlide object. No other threads may be using the object. After this call returns, the object cannot be used anymore.
openslide_detect_vendor
Quickly determine whether a whole slide image is recognized.
openslide_get_associated_image_dimensions
Get the dimensions of an associated image.
openslide_get_associated_image_names
Get the NULL-terminated array of associated image names.
openslide_get_best_layer_for_downsample
Get the best level to use for displaying the given downsample.
openslide_get_best_level_for_downsample
Get the best level to use for displaying the given downsample.
openslide_get_comment
Get the comment (if any) for this image. Exactly equivalent to calling openslide_get_property_value() with #OPENSLIDE_PROPERTY_NAME_COMMENT.
openslide_get_error
Get the current error string.
openslide_get_layer0_dimensions
Get the dimensions of level 0 (the largest level). Exactly equivalent to calling openslide_get_level_dimensions(osr, 0, w, h).
openslide_get_layer_count
Get the number of levels in the whole slide image.
openslide_get_layer_dimensions
Get the dimensions of a level.
openslide_get_layer_downsample
Get the downsampling factor of a given level.
openslide_get_level0_dimensions
Get the dimensions of level 0 (the largest level). Exactly equivalent to calling openslide_get_level_dimensions(osr, 0, w, h).
openslide_get_level_count
Get the number of levels in the whole slide image.
openslide_get_level_dimensions
Get the dimensions of a level.
openslide_get_level_downsample
Get the downsampling factor of a given level.
openslide_get_property_names
Get the NULL-terminated array of property names.
openslide_get_property_value
Get the value of a single property.
openslide_get_version
Get the version of the OpenSlide library.
openslide_open
Open a whole slide image.
openslide_read_associated_image
Copy pre-multiplied ARGB data from an associated image.
openslide_read_region
Copy pre-multiplied ARGB data from a whole slide image.

Type Aliases

__blkcnt64_t
__blkcnt_t
__blksize_t
__caddr_t
__clock_t
__clockid_t
__daddr_t
__dev_t
__fsblkcnt64_t
__fsblkcnt_t
__fsfilcnt64_t
__fsfilcnt_t
__fsword_t
__gid_t
__id_t
__ino64_t
__ino_t
__int8_t
__int16_t
__int32_t
__int64_t
__int_least8_t
__int_least16_t
__int_least32_t
__int_least64_t
__intmax_t
__intptr_t
__key_t
__loff_t
__mode_t
__nlink_t
__off64_t
__off_t
__pid_t
__quad_t
__rlim64_t
__rlim_t
__sig_atomic_t
__socklen_t
__ssize_t
__suseconds64_t
__suseconds_t
__syscall_slong_t
__syscall_ulong_t
__time_t
__timer_t
__u_char
__u_int
__u_long
__u_quad_t
__u_short
__uid_t
__uint8_t
__uint16_t
__uint32_t
__uint64_t
__uint_least8_t
__uint_least16_t
__uint_least32_t
__uint_least64_t
__uintmax_t
__useconds_t
int_fast8_t
int_fast16_t
int_fast32_t
int_fast64_t
int_least8_t
int_least16_t
int_least32_t
int_least64_t
intmax_t
openslide_t
The main OpenSlide type.
uint_fast8_t
uint_fast16_t
uint_fast32_t
uint_fast64_t
uint_least8_t
uint_least16_t
uint_least32_t
uint_least64_t
uintmax_t