openslide_get_error

Function openslide_get_error 

pub unsafe extern "C" fn openslide_get_error(
    osr: *mut openslide_t,
) -> *const c_char
Get the current error string.

For a given OpenSlide object, once this function returns a non-NULL value, the only useful operation on the object is to call openslide_close() to free its resources.

@param osr The OpenSlide object. @return A string describing the original error that caused the problem, or NULL if no error has occurred. @since 3.2.0