Structs
Constants
- INT8_
MAX - INT8_
MIN - INT16_
MAX - INT16_
MIN - INT32_
MAX - INT32_
MIN - INTPTR_
MAX - INTPTR_
MIN - INT_
FAST8_ MAX - INT_
FAST8_ MIN - INT_
FAST16_ MAX - INT_
FAST16_ MIN - INT_
FAST32_ MAX - INT_
FAST32_ MIN - INT_
LEAS T8_ MAX - INT_
LEAS T8_ MIN - INT_
LEAS T16_ MAX - INT_
LEAS T16_ MIN - INT_
LEAS T32_ MAX - INT_
LEAS T32_ MIN - OPENSLIDE_
PROPERTY_ NAME_ BACKGROUND_ COLOR - OPENSLIDE_
PROPERTY_ NAME_ BOUNDS_ HEIGHT - OPENSLIDE_
PROPERTY_ NAME_ BOUNDS_ WIDTH - OPENSLIDE_
PROPERTY_ NAME_ BOUNDS_ X - OPENSLIDE_
PROPERTY_ NAME_ BOUNDS_ Y - OPENSLIDE_
PROPERTY_ NAME_ COMMENT - OPENSLIDE_
PROPERTY_ NAME_ MPP_ X - OPENSLIDE_
PROPERTY_ NAME_ MPP_ Y - OPENSLIDE_
PROPERTY_ NAME_ OBJECTIVE_ POWER - OPENSLIDE_
PROPERTY_ NAME_ QUICKHAS H1 - OPENSLIDE_
PROPERTY_ NAME_ VENDOR - PTRDIFF_
MAX - PTRDIFF_
MIN - SIG_
ATOMIC_ MAX - SIG_
ATOMIC_ MIN - SIZE_
MAX - UINT8_
MAX - UINT16_
MAX - UINT32_
MAX - UINTPTR_
MAX - UINT_
FAST8_ MAX - UINT_
FAST16_ MAX - UINT_
FAST32_ MAX - UINT_
LEAS T8_ MAX - UINT_
LEAS T16_ MAX - UINT_
LEAS T32_ MAX - WINT_
MAX - WINT_
MIN - _ATFILE_
SOURCE - _BITS_
STDINT_ INTN_ H - _BITS_
STDINT_ LEAST_ H - _BITS_
STDINT_ UINTN_ H - _BITS_
TIME64_ H - _BITS_
TYPESIZES_ H - _BITS_
TYPES_ H - _BITS_
WCHAR_ H - _DEFAULT_
SOURCE - _FEATURES_
H - _POSIX_
C_ SOURCE - _POSIX_
SOURCE - _STDC_
PREDEF_ H - _STDINT_
H - _SYS_
CDEFS_ H - __
FD_ SETSIZE - __
GLIBC_ MINOR__ - __
GLIBC_ USE_ C2X_ STRTOL - __
GLIBC_ USE_ DEPRECATED_ GETS - __
GLIBC_ USE_ DEPRECATED_ SCANF - __
GLIBC_ USE_ IEC_ 60559_ BFP_ EXT - __
GLIBC_ USE_ IEC_ 60559_ BFP_ EXT_ C2X - __
GLIBC_ USE_ IEC_ 60559_ EXT - __
GLIBC_ USE_ IEC_ 60559_ FUNCS_ EXT - __
GLIBC_ USE_ IEC_ 60559_ FUNCS_ EXT_ C2X - __
GLIBC_ USE_ IEC_ 60559_ TYPES_ EXT - __
GLIBC_ USE_ ISOC2X - __
GLIBC_ USE_ LIB_ EXT2 - __
GLIBC__ - __
GNU_ LIBRARY__ - __
HAVE_ GENERIC_ SELECTION - __
INO_ T_ MATCHES_ INO64_ T - __
KERNEL_ OLD_ TIMEVAL_ MATCHES_ TIMEVA L64 - __
LDOUBLE_ REDIRECTS_ TO_ FLOA T128_ ABI - __
OFF_ T_ MATCHES_ OFF64_ T - __
RLIM_ T_ MATCHES_ RLIM64_ T - __
STATFS_ MATCHES_ STATF S64 - __
STDC_ IEC_ 559_ COMPLEX__ - __
STDC_ IEC_ 559__ - __
STDC_ IEC_ 60559_ BFP__ - __
STDC_ IEC_ 60559_ COMPLEX__ - __
STDC_ ISO_ 10646__ - __
SYSCALL_ WORDSIZE - __
TIMESIZE - __
USE_ ATFILE - __
USE_ FORTIFY_ LEVEL - __
USE_ ISOC11 - __
USE_ ISOC95 - __
USE_ ISOC99 - __
USE_ MISC - __
USE_ POSIX - __
USE_ POSI X2 - __
USE_ POSI X199309 - __
USE_ POSI X199506 - __
USE_ POSIX_ IMPLICITLY - __
USE_ XOPE N2K - __
USE_ XOPE N2K8 - __
WORDSIZE - __
WORDSIZE_ TIME64_ COMPA T32 - __
bool_ true_ false_ are_ defined - __
glibc_ c99_ flexarr_ available - false_
- true_
Functions
- _openslide_
cancel_ ⚠prefetch_ hint_ UNIMPLEMENTED - _openslide_
give_ ⚠prefetch_ hint_ UNIMPLEMENTED - openslide_
can_ ⚠open - Return whether openslide_open() will succeed.
- openslide_
close ⚠ - Close an OpenSlide object. No other threads may be using the object. After this call returns, the object cannot be used anymore.
- openslide_
detect_ ⚠vendor - Quickly determine whether a whole slide image is recognized.
- openslide_
get_ ⚠associated_ image_ dimensions - Get the dimensions of an associated image.
- openslide_
get_ ⚠associated_ image_ names - Get the NULL-terminated array of associated image names.
- openslide_
get_ ⚠best_ layer_ for_ downsample - Get the best level to use for displaying the given downsample.
- openslide_
get_ ⚠best_ level_ for_ downsample - Get the best level to use for displaying the given downsample.
- openslide_
get_ ⚠comment - Get the comment (if any) for this image. Exactly equivalent to calling openslide_get_property_value() with #OPENSLIDE_PROPERTY_NAME_COMMENT.
- openslide_
get_ ⚠error - Get the current error string.
- openslide_
get_ ⚠layer0_ dimensions - Get the dimensions of level 0 (the largest level). Exactly equivalent to calling openslide_get_level_dimensions(osr, 0, w, h).
- openslide_
get_ ⚠layer_ count - Get the number of levels in the whole slide image.
- openslide_
get_ ⚠layer_ dimensions - Get the dimensions of a level.
- openslide_
get_ ⚠layer_ downsample - Get the downsampling factor of a given level.
- openslide_
get_ ⚠level0_ dimensions - Get the dimensions of level 0 (the largest level). Exactly equivalent to calling openslide_get_level_dimensions(osr, 0, w, h).
- openslide_
get_ ⚠level_ count - Get the number of levels in the whole slide image.
- openslide_
get_ ⚠level_ dimensions - Get the dimensions of a level.
- openslide_
get_ ⚠level_ downsample - Get the downsampling factor of a given level.
- openslide_
get_ ⚠property_ names - Get the NULL-terminated array of property names.
- openslide_
get_ ⚠property_ value - Get the value of a single property.
- openslide_
get_ ⚠version - Get the version of the OpenSlide library.
- openslide_
open ⚠ - Open a whole slide image.
- openslide_
read_ ⚠associated_ image - Copy pre-multiplied ARGB data from an associated image.
- openslide_
read_ ⚠region - Copy pre-multiplied ARGB data from a whole slide image.
Type Aliases
- __
blkcnt64_ t - __
blkcnt_ t - __
blksize_ t - __
caddr_ t - __
clock_ t - __
clockid_ t - __
daddr_ t - __dev_t
- __
fsblkcnt64_ t - __
fsblkcnt_ t - __
fsfilcnt64_ t - __
fsfilcnt_ t - __
fsword_ t - __gid_t
- __id_t
- __
ino64_ t - __ino_t
- __
int8_ t - __
int16_ t - __
int32_ t - __
int64_ t - __
int_ least8_ t - __
int_ least16_ t - __
int_ least32_ t - __
int_ least64_ t - __
intmax_ t - __
intptr_ t - __key_t
- __
loff_ t - __
mode_ t - __
nlink_ t - __
off64_ t - __off_t
- __pid_t
- __
quad_ t - __
rlim64_ t - __
rlim_ t - __
sig_ atomic_ t - __
socklen_ t - __
ssize_ t - __
suseconds64_ t - __
suseconds_ t - __
syscall_ slong_ t - __
syscall_ ulong_ t - __
time_ t - __
timer_ t - __
u_ char - __u_int
- __
u_ long - __
u_ quad_ t - __
u_ short - __uid_t
- __
uint8_ t - __
uint16_ t - __
uint32_ t - __
uint64_ t - __
uint_ least8_ t - __
uint_ least16_ t - __
uint_ least32_ t - __
uint_ least64_ t - __
uintmax_ t - __
useconds_ t - int_
fast8_ t - int_
fast16_ t - int_
fast32_ t - int_
fast64_ t - int_
least8_ t - int_
least16_ t - int_
least32_ t - int_
least64_ t - intmax_
t - openslide_
t - The main OpenSlide type.
- uint_
fast8_ t - uint_
fast16_ t - uint_
fast32_ t - uint_
fast64_ t - uint_
least8_ t - uint_
least16_ t - uint_
least32_ t - uint_
least64_ t - uintmax_
t